import { MockedResponse } from '@apollo/client/testing';
import { ApolloClient, ApolloClientOptions, ApolloLink, FetchResult, InMemoryCache, InMemoryCacheConfig, NormalizedCacheObject, OperationVariables } from '@apollo/client';
import { GraphQLError, IntrospectionQuery, DocumentNode } from 'graphql';
import { ITypeDefinitions, IMocks, IResolvers } from 'graphql-tools';
export declare type ResultFunction<T> = () => T;
export declare function fetchGraphQLSchema(url: string, readable?: boolean, init?: RequestInit): Promise<ITypeDefinitions>;
interface CreateLinkOptions {
    delay?: number;
}
export declare function createErrorLink(graphQLError?: string | GraphQLError[]): ApolloLink;
export declare function createLoadingLink(): ApolloLink;
export interface LinkSchemaProps extends CreateLinkOptions {
    resolvers: IMocks;
    introspectionResult: IntrospectionQuery | any;
    typeResolvers?: IResolvers;
    rootValue?: any;
    context?: any;
}
export interface CreateApolloClient {
    mocks: ReadonlyArray<MockedResponse> | LinkSchemaProps;
    cacheOptions?: InMemoryCacheConfig;
    clientOptions?: ApolloClientOptions<NormalizedCacheObject>;
    links?: (cache?: InMemoryCache) => ApolloLink[];
    addTypename?: boolean;
}
export declare function createApolloClient({ mocks, cacheOptions, clientOptions, links, addTypename, }: CreateApolloClient): ApolloClient<NormalizedCacheObject>;
export declare function createGraphQLErrorMessage(graphQLError?: string | GraphQLError[]): GraphQLError[];
interface CreateMocksOptions<TData, TVariables> {
    data: TData;
    variables?: TVariables;
    newData?: ResultFunction<FetchResult>;
    delay?: number;
    graphqlErrors?: string | GraphQLError[];
    error?: Error;
}
export declare function createMocks<TData, TVariables = OperationVariables>(query: DocumentNode, { variables, data, newData, graphqlErrors, error, delay, }: CreateMocksOptions<TData, TVariables>): MockedResponse[];
export {};
